@@ -1,6 +1,7 @@
 ﻿import sys
 from PySide2 import QtCore
 from PySide2.QtWidgets import QApplication, QFileDialog, QWidget
+import platform
 
 if not QApplication.instance():
     app = QApplication(sys.argv)
@@ -9,11 +10,11 @@ else:
 
 dialog = QFileDialog()
 dialog.setFileMode(QFileDialog.Directory)
-dialog.setOption(QFileDialog.DontUseNativeDialog, True)
 dialog.setWindowState(dialog.windowState() & ~QtCore.Qt.WindowMinimized | QtCore.Qt.WindowActive)
-dialog.activateWindow()
-dialog.setWindowFlags(dialog.windowFlags() | QtCore.Qt.WindowStaysOnTopHint)
-dialog.show()
+
+if (platform.system() == "Windows"):
+    dialog.setWindowFlags(dialog.windowFlags() | QtCore.Qt.WindowStaysOnTopHint)
+    dialog.show()
 
 if dialog.exec_():
     fileName = dialog.selectedFiles()
